package
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Nov 6, 2020
License: GPL-3.0
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type FileInfo struct {
FileId string `bson:"FileId"`
FileName string `bson:"FileName"`
FileSize int64 `bson:"FileSize"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.